@@ -35,11 +35,14 @@ sub generate {
 __DATA__
 
 @@ cpanfile
-on test => sub {
-    requires 'Test::More', 0.98;
+on 'configure' => sub {
 };
 
-on configure => sub {
+on 'build' => sub {
+};
+
+on 'test' => sub {
+    requires 'Test::More', '0.98';
 };
 
 on 'develop' => sub {
